@@ -1,11 +1,10 @@
 #import <objectbase/SwarmObject.h>
-#import <collections.h>
 #import "MemLogConsumer.h"
 
 @interface AsciiMemLogger : SwarmObject <MemLogConsumer> 
 {
   id myStream;
-  id <Map> myObjects;
+  id myObjects;
   const char *myRecordDelim, *myDataDelim;
   BOOL isCumulative;
 }
