@@ -1,11 +1,12 @@
 #import <objectbase/SwarmObject.h>
+#import "Hashtable.h"
 #import "MemLogConsumer.h"
 
 // KISS stands for Keep it simple, stupid.
 
 @interface KISSMemLogger : SwarmObject <MemLogConsumer>
 {
-	id <Map> myObjects;  // would need a lib from GNUstep for a hashtable
+	Hashtable* myObjects;  // would need a lib from GNUstep for a hashtable
 	id <List> myTexts;
 	id myCanvas;
 	int updateEvery, isCanvasDestroyed, lastTime;
