@@ -1,6 +1,9 @@
 #import <objectbase/SwarmObject.h>
 #import <defobj/Create.h>
 #import <defobj/defalloc.h>
+#import "AsciiMemLogger.h"
+#import "KISSMemLogger.h"
+#import "RMemLogger.h"
 #import "MemLogConsumer.h"
 
 @interface LoggingZone : SwarmObject
